import 'package:protonimage/src/core/dependencies.dart';

// Accessing the configurations from BaseShimmerConfig
Color baseColor = BaseShimmerConfig.baseColor;
Color highlightColor = BaseShimmerConfig.highlightColor;
Color blackColor = BaseShimmerConfig.blackColor;
Color whiteColor = BaseShimmerConfig.whiteColor;

// Accessing the configurations from BaseComponentConfig
double aspectRatio = BaseComponentConfig.aspectRatio;
BoxFit boxFit = BaseComponentConfig.boxFit;

class ProtonImage extends StatelessWidget {
  // Required
  final String path; // URl path
  final double height; // Container Height
  final double radius; // Container Radious

  // Optional
  final BoxFit imgBoxfit; // Image Boxfit - cover
  final double aspectRatio; // Aspect Ration 1:1
  final Color baseColor; // Base Color -  grey
  final Color highlightColor; // Higlight Color  -  grey shade
  final Color backgroundColor; // Background COlor - white
  final Gradient?
      overlayGradient; // Overlay - default set no gradient - nullable

  const ProtonImage({
    super.key,
    required this.path,
    required this.height,
    required this.radius,
    this.imgBoxfit = BaseComponentConfig.boxFit, // BoxFit cover
    this.aspectRatio = BaseComponentConfig.aspectRatio, // Aspect ratio 1:1
    this.backgroundColor =
        BaseShimmerConfig.whiteColor, // Equivalent to Colors.white
    this.baseColor =
        BaseShimmerConfig.baseColor, // Equivalent to Colors.grey.shade300
    this.highlightColor =
        BaseShimmerConfig.highlightColor, // Equivalent to Colors.grey.shade100
    this.overlayGradient,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: height, // General Container Height
      child: AspectRatio(
        aspectRatio: aspectRatio, // Core Aspect Ratio
        child: Stack(
          children: [
            Transform.scale(
              scale: BaseComponentConfig
                  .transferScale, // Scallig down shimmer by 0.01
              child: Shimmer.fromColors(
                baseColor: baseColor, // User Selected Colors
                highlightColor: highlightColor, // User Selected Colors
                child: Container(
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(radius),
                    color: backgroundColor,
                  ),
                ),
              ),
            ),
            Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(radius),
                image: DecorationImage(
                  fit: imgBoxfit, // Live Image URL
                  image: NetworkImage(path),
                ),
                gradient: overlayGradient,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
